Citing LumiSpy
**************

LumiSpy is maintained by an `active community of developers 
<https://github.com/lumispy/lumispy/contributors>`_.

If you use LumiSpy for your research projects, please consider citing
it in your publications. LumiSpy and `HyperSpy <https://hyperspy.org>`_
are made by scientists and volunteers who generously donate their time
and attention. Citations help us justify the effort that goes into
building and maintaining this project.

The DOI in the badge below is the `Concept DOI
<https://support.zenodo.org/help/en-gb/1-upload-deposit/97-what-is-doi-versioning>`_ --
it can be used to cite the project without referring to a specific
version. If you are citing LumiSpy because you have used it to process data,
please use the DOI of the specific version that you have employed. You can
find it by clicking on the DOI badge:

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.4640445.svg
   :target: https://doi.org/10.5281/zenodo.4640445

DOIs for the LumiSpy project are provided by the `Zenodo <https://zenodo.org>`_
repository.

If the LumiSpy project has proven useful for your work, please consider awarding a
star to our `github repository <https://github.com/lumispy/lumispy/stargazers>`_.
